# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from alphausblue.api import operation_pb2 as api_dot_operation__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from alphausblue.operations.v1 import operations_pb2 as operations_dot_v1_dot_operations__pb2


class OperationsStub(object):
    """Manages long-running operations with an API service.

    When an API method normally takes long time to complete, it can be designed
    to return [Operation][google.longrunning.Operation] to the client, and the client can use this
    interface to receive the real response asynchronously by polling the
    operation resource, or pass the operation resource to another API (such as
    Google Cloud Pub/Sub API) to receive the response.  Any API service that
    returns long-running operations should implement the `Operations` interface
    so developers can have a consistent client experience.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListOperations = channel.unary_stream(
                '/blueapi.operations.v1.Operations/ListOperations',
                request_serializer=operations_dot_v1_dot_operations__pb2.ListOperationsRequest.SerializeToString,
                response_deserializer=api_dot_operation__pb2.Operation.FromString,
                )
        self.GetOperation = channel.unary_unary(
                '/blueapi.operations.v1.Operations/GetOperation',
                request_serializer=operations_dot_v1_dot_operations__pb2.GetOperationRequest.SerializeToString,
                response_deserializer=api_dot_operation__pb2.Operation.FromString,
                )
        self.DeleteOperation = channel.unary_unary(
                '/blueapi.operations.v1.Operations/DeleteOperation',
                request_serializer=operations_dot_v1_dot_operations__pb2.DeleteOperationRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CancelOperation = channel.unary_unary(
                '/blueapi.operations.v1.Operations/CancelOperation',
                request_serializer=operations_dot_v1_dot_operations__pb2.CancelOperationRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.WaitOperation = channel.unary_unary(
                '/blueapi.operations.v1.Operations/WaitOperation',
                request_serializer=operations_dot_v1_dot_operations__pb2.WaitOperationRequest.SerializeToString,
                response_deserializer=api_dot_operation__pb2.Operation.FromString,
                )


class OperationsServicer(object):
    """Manages long-running operations with an API service.

    When an API method normally takes long time to complete, it can be designed
    to return [Operation][google.longrunning.Operation] to the client, and the client can use this
    interface to receive the real response asynchronously by polling the
    operation resource, or pass the operation resource to another API (such as
    Google Cloud Pub/Sub API) to receive the response.  Any API service that
    returns long-running operations should implement the `Operations` interface
    so developers can have a consistent client experience.
    """

    def ListOperations(self, request, context):
        """Lists long-running operations.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOperation(self, request, context):
        """Gets the latest state of a long-running operation. You can use this method to
        poll the operation result at intervals.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOperation(self, request, context):
        """Deletes a long-running operation. This method indicates that the client is no
        longer interested in the operation result. It does not cancel the operation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelOperation(self, request, context):
        """Starts asynchronous cancellation on a long-running operation. The server makes
        a best effort to cancel the operation, but success is not guaranteed. On successful
        cancellation, the operation is not deleted; instead, it becomes an operation with
        a value of [google.rpc.Status.code][google.rpc.Status.code] 1, corresponding
        to `Code.CANCELLED`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WaitOperation(self, request, context):
        """Waits for the specified long-running operation until it is done or reaches
        at most a specified timeout, returning the latest state. If the operation
        is already done, the latest state is immediately returned. If the timeout
        specified is greater than the default HTTP/RPC timeout, the HTTP/RPC
        timeout is used. If the server does not support this method, it returns
        `google.rpc.Code.UNIMPLEMENTED`.
        Note that this method is on a best-effort basis. It may return the latest
        state before the specified timeout (including immediately), meaning, even an
        immediate response is no guarantee that the operation is done.
        At the moment, Blue's default RPC timeout is around one hour.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OperationsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListOperations': grpc.unary_stream_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=operations_dot_v1_dot_operations__pb2.ListOperationsRequest.FromString,
                    response_serializer=api_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOperation,
                    request_deserializer=operations_dot_v1_dot_operations__pb2.GetOperationRequest.FromString,
                    response_serializer=api_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeleteOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOperation,
                    request_deserializer=operations_dot_v1_dot_operations__pb2.DeleteOperationRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CancelOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelOperation,
                    request_deserializer=operations_dot_v1_dot_operations__pb2.CancelOperationRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'WaitOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.WaitOperation,
                    request_deserializer=operations_dot_v1_dot_operations__pb2.WaitOperationRequest.FromString,
                    response_serializer=api_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'blueapi.operations.v1.Operations', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Operations(object):
    """Manages long-running operations with an API service.

    When an API method normally takes long time to complete, it can be designed
    to return [Operation][google.longrunning.Operation] to the client, and the client can use this
    interface to receive the real response asynchronously by polling the
    operation resource, or pass the operation resource to another API (such as
    Google Cloud Pub/Sub API) to receive the response.  Any API service that
    returns long-running operations should implement the `Operations` interface
    so developers can have a consistent client experience.
    """

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/blueapi.operations.v1.Operations/ListOperations',
            operations_dot_v1_dot_operations__pb2.ListOperationsRequest.SerializeToString,
            api_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.operations.v1.Operations/GetOperation',
            operations_dot_v1_dot_operations__pb2.GetOperationRequest.SerializeToString,
            api_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.operations.v1.Operations/DeleteOperation',
            operations_dot_v1_dot_operations__pb2.DeleteOperationRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.operations.v1.Operations/CancelOperation',
            operations_dot_v1_dot_operations__pb2.CancelOperationRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WaitOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/blueapi.operations.v1.Operations/WaitOperation',
            operations_dot_v1_dot_operations__pb2.WaitOperationRequest.SerializeToString,
            api_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: billing/v1/billing.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from alphausblue.api import account_pb2 as api_dot_account__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='billing/v1/billing.proto',
  package='blueapi.billing.v1',
  syntax='proto3',
  serialized_options=b'\n\031cloud.alphaus.api.billingB\014BillingProtoZ&github.com/alphauslabs/blueapi/billing',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18\x62illing/v1/billing.proto\x12\x12\x62lueapi.billing.v1\x1a\x11\x61pi/account.proto\x1a\x1cgoogle/api/annotations.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"\x83\x01\n\x0c\x42illingGroup\x12\x19\n\x11\x62illingInternalId\x18\x01 \x01(\t\x12\x16\n\x0e\x62illingGroupId\x18\x02 \x01(\t\x12\x18\n\x10\x62illingGroupName\x18\x03 \x01(\t\x12&\n\x08\x61\x63\x63ounts\x18\x04 \x03(\x0b\x32\x14.blueapi.api.Account\"\x1a\n\x18ListBillingGroupsRequest\"\xf1\x02\n\x19\x43reateBillingGroupRequest\x12\x16\n\x0e\x62illingGroupId\x18\x01 \x01(\t\x12\x18\n\x10\x62illingGroupName\x18\x02 \x01(\t\x12\x13\n\x0b\x63ompanyName\x18\x03 \x01(\t\x12\x14\n\x0c\x62illingTitle\x18\x04 \x01(\t\x12\x13\n\x0bphoneNumber\x18\x05 \x01(\t\x12\x12\n\npostalCode\x18\x06 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x07 \x01(\t\x12\x10\n\x08personal\x18\x08 \x01(\t\x12\x0f\n\x07remarks\x18\t \x01(\t\x12\x11\n\tprojectId\x18\n \x01(\t\x12\x10\n\x08language\x18\x0b \x01(\t\x12\x13\n\x0b\x64isplayCost\x18\x0c \x01(\t\x12\x18\n\x10\x65xchangeRateType\x18\r \x01(\t\x12\x46\n\x08invoices\x18\x0e \x01(\x0b\x32\x34.blueapi.billing.v1.CreateBillingGroupRequestInvoice\"\xff\x01\n CreateBillingGroupRequestInvoice\x12G\n\x03\x61ws\x18\x01 \x01(\x0b\x32:.blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor\x12I\n\x05\x61zure\x18\x02 \x01(\x0b\x32:.blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor\x12G\n\x03gcp\x18\x03 \x01(\x0b\x32:.blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor\"\xd7\x03\n&CreateBillingGroupRequestInvoiceVendor\x12\x10\n\x08\x63\x61lcType\x18\x01 \x01(\t\x12\x14\n\x0c\x64iscountRate\x18\x02 \x01(\x01\x12\x17\n\x0fsubstitutionFee\x18\x03 \x01(\t\x12\x17\n\x0fsubstitutionFix\x18\x04 \x01(\x01\x12\x18\n\x10substitutionRate\x18\x05 \x01(\x01\x12\x12\n\nsupportFee\x18\x06 \x01(\t\x12\x13\n\x0bsupportRate\x18\x07 \x01(\x01\x12\x12\n\nsupportFix\x18\x08 \x01(\x01\x12\x0f\n\x07taxRate\x18\t \x01(\x01\x12\x10\n\x08\x63urrency\x18\n \x01(\t\x12\x1b\n\x13\x64iscountTargetUsage\x18\x0b \x01(\t\x12\"\n\x1asubstitutionFeeTargetUsage\x18\x0c \x01(\t\x12\x19\n\x11\x64iscountCalcLogic\x18\r \x01(\t\x12!\n\x19substitutionFeeCalcTarget\x18\x0e \x01(\t\x12\x1f\n\x17substitutionFeeCalcType\x18\x0f \x01(\t\x12\x1b\n\x13supportAmountTarget\x18\x10 \x01(\t\x12\x1c\n\x14supportFeeCalcTarget\x18\x11 \x01(\t\"3\n\x16GetBillingGroupRequest\x12\x19\n\x11\x62illingInternalId\x18\x01 \x01(\t\"Q\n\x17GetBillingGroupResponse\x12\x36\n\x0c\x62illingGroup\x18\x01 \x01(\x0b\x32 .blueapi.billing.v1.BillingGroup2\xce\x04\n\x07\x42illing\x12\x80\x01\n\x11ListBillingGroups\x12,.blueapi.billing.v1.ListBillingGroupsRequest\x1a .blueapi.billing.v1.BillingGroup\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/billinggroups0\x01\x12\x83\x01\n\x12\x43reateBillingGroup\x12-.blueapi.billing.v1.CreateBillingGroupRequest\x1a .blueapi.billing.v1.BillingGroup\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/billinggroups:\x01*\x12\x99\x01\n\x0fGetBillingGroup\x12*.blueapi.billing.v1.GetBillingGroupRequest\x1a+.blueapi.billing.v1.GetBillingGroupResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/v1/billinggroups/{billingInternalId}\x1a\x9d\x01\x92\x41\x99\x01\x12\x46(BETA) Billing API. Base URL: https://api.alphaus.cloud/m/blue/billing\x1aO\n\x12Service definition\x12\x39https://github.com/alphauslabs/blueapi/tree/main/billing/BQ\n\x19\x63loud.alphaus.api.billingB\x0c\x42illingProtoZ&github.com/alphauslabs/blueapi/billingb\x06proto3'
  ,
  dependencies=[api_dot_account__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,protoc__gen__openapiv2_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_BILLINGGROUP = _descriptor.Descriptor(
  name='BillingGroup',
  full_name='blueapi.billing.v1.BillingGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='billingInternalId', full_name='blueapi.billing.v1.BillingGroup.billingInternalId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billingGroupId', full_name='blueapi.billing.v1.BillingGroup.billingGroupId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billingGroupName', full_name='blueapi.billing.v1.BillingGroup.billingGroupName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accounts', full_name='blueapi.billing.v1.BillingGroup.accounts', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=277,
)


_LISTBILLINGGROUPSREQUEST = _descriptor.Descriptor(
  name='ListBillingGroupsRequest',
  full_name='blueapi.billing.v1.ListBillingGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=305,
)


_CREATEBILLINGGROUPREQUEST = _descriptor.Descriptor(
  name='CreateBillingGroupRequest',
  full_name='blueapi.billing.v1.CreateBillingGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='billingGroupId', full_name='blueapi.billing.v1.CreateBillingGroupRequest.billingGroupId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billingGroupName', full_name='blueapi.billing.v1.CreateBillingGroupRequest.billingGroupName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='companyName', full_name='blueapi.billing.v1.CreateBillingGroupRequest.companyName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billingTitle', full_name='blueapi.billing.v1.CreateBillingGroupRequest.billingTitle', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phoneNumber', full_name='blueapi.billing.v1.CreateBillingGroupRequest.phoneNumber', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='postalCode', full_name='blueapi.billing.v1.CreateBillingGroupRequest.postalCode', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='blueapi.billing.v1.CreateBillingGroupRequest.address', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='personal', full_name='blueapi.billing.v1.CreateBillingGroupRequest.personal', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remarks', full_name='blueapi.billing.v1.CreateBillingGroupRequest.remarks', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='projectId', full_name='blueapi.billing.v1.CreateBillingGroupRequest.projectId', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='blueapi.billing.v1.CreateBillingGroupRequest.language', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='displayCost', full_name='blueapi.billing.v1.CreateBillingGroupRequest.displayCost', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchangeRateType', full_name='blueapi.billing.v1.CreateBillingGroupRequest.exchangeRateType', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invoices', full_name='blueapi.billing.v1.CreateBillingGroupRequest.invoices', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=308,
  serialized_end=677,
)


_CREATEBILLINGGROUPREQUESTINVOICE = _descriptor.Descriptor(
  name='CreateBillingGroupRequestInvoice',
  full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aws', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoice.aws', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='azure', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoice.azure', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gcp', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoice.gcp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=680,
  serialized_end=935,
)


_CREATEBILLINGGROUPREQUESTINVOICEVENDOR = _descriptor.Descriptor(
  name='CreateBillingGroupRequestInvoiceVendor',
  full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='calcType', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor.calcType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discountRate', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor.discountRate', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='substitutionFee', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor.substitutionFee', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='substitutionFix', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor.substitutionFix', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='substitutionRate', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor.substitutionRate', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supportFee', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor.supportFee', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supportRate', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor.supportRate', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supportFix', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor.supportFix', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taxRate', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor.taxRate', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor.currency', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discountTargetUsage', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor.discountTargetUsage', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='substitutionFeeTargetUsage', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor.substitutionFeeTargetUsage', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discountCalcLogic', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor.discountCalcLogic', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='substitutionFeeCalcTarget', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor.substitutionFeeCalcTarget', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='substitutionFeeCalcType', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor.substitutionFeeCalcType', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supportAmountTarget', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor.supportAmountTarget', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supportFeeCalcTarget', full_name='blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor.supportFeeCalcTarget', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=938,
  serialized_end=1409,
)


_GETBILLINGGROUPREQUEST = _descriptor.Descriptor(
  name='GetBillingGroupRequest',
  full_name='blueapi.billing.v1.GetBillingGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='billingInternalId', full_name='blueapi.billing.v1.GetBillingGroupRequest.billingInternalId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1411,
  serialized_end=1462,
)


_GETBILLINGGROUPRESPONSE = _descriptor.Descriptor(
  name='GetBillingGroupResponse',
  full_name='blueapi.billing.v1.GetBillingGroupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='billingGroup', full_name='blueapi.billing.v1.GetBillingGroupResponse.billingGroup', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1464,
  serialized_end=1545,
)

_BILLINGGROUP.fields_by_name['accounts'].message_type = api_dot_account__pb2._ACCOUNT
_CREATEBILLINGGROUPREQUEST.fields_by_name['invoices'].message_type = _CREATEBILLINGGROUPREQUESTINVOICE
_CREATEBILLINGGROUPREQUESTINVOICE.fields_by_name['aws'].message_type = _CREATEBILLINGGROUPREQUESTINVOICEVENDOR
_CREATEBILLINGGROUPREQUESTINVOICE.fields_by_name['azure'].message_type = _CREATEBILLINGGROUPREQUESTINVOICEVENDOR
_CREATEBILLINGGROUPREQUESTINVOICE.fields_by_name['gcp'].message_type = _CREATEBILLINGGROUPREQUESTINVOICEVENDOR
_GETBILLINGGROUPRESPONSE.fields_by_name['billingGroup'].message_type = _BILLINGGROUP
DESCRIPTOR.message_types_by_name['BillingGroup'] = _BILLINGGROUP
DESCRIPTOR.message_types_by_name['ListBillingGroupsRequest'] = _LISTBILLINGGROUPSREQUEST
DESCRIPTOR.message_types_by_name['CreateBillingGroupRequest'] = _CREATEBILLINGGROUPREQUEST
DESCRIPTOR.message_types_by_name['CreateBillingGroupRequestInvoice'] = _CREATEBILLINGGROUPREQUESTINVOICE
DESCRIPTOR.message_types_by_name['CreateBillingGroupRequestInvoiceVendor'] = _CREATEBILLINGGROUPREQUESTINVOICEVENDOR
DESCRIPTOR.message_types_by_name['GetBillingGroupRequest'] = _GETBILLINGGROUPREQUEST
DESCRIPTOR.message_types_by_name['GetBillingGroupResponse'] = _GETBILLINGGROUPRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BillingGroup = _reflection.GeneratedProtocolMessageType('BillingGroup', (_message.Message,), {
  'DESCRIPTOR' : _BILLINGGROUP,
  '__module__' : 'billing.v1.billing_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.billing.v1.BillingGroup)
  })
_sym_db.RegisterMessage(BillingGroup)

ListBillingGroupsRequest = _reflection.GeneratedProtocolMessageType('ListBillingGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBILLINGGROUPSREQUEST,
  '__module__' : 'billing.v1.billing_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.billing.v1.ListBillingGroupsRequest)
  })
_sym_db.RegisterMessage(ListBillingGroupsRequest)

CreateBillingGroupRequest = _reflection.GeneratedProtocolMessageType('CreateBillingGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBILLINGGROUPREQUEST,
  '__module__' : 'billing.v1.billing_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.billing.v1.CreateBillingGroupRequest)
  })
_sym_db.RegisterMessage(CreateBillingGroupRequest)

CreateBillingGroupRequestInvoice = _reflection.GeneratedProtocolMessageType('CreateBillingGroupRequestInvoice', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBILLINGGROUPREQUESTINVOICE,
  '__module__' : 'billing.v1.billing_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.billing.v1.CreateBillingGroupRequestInvoice)
  })
_sym_db.RegisterMessage(CreateBillingGroupRequestInvoice)

CreateBillingGroupRequestInvoiceVendor = _reflection.GeneratedProtocolMessageType('CreateBillingGroupRequestInvoiceVendor', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBILLINGGROUPREQUESTINVOICEVENDOR,
  '__module__' : 'billing.v1.billing_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.billing.v1.CreateBillingGroupRequestInvoiceVendor)
  })
_sym_db.RegisterMessage(CreateBillingGroupRequestInvoiceVendor)

GetBillingGroupRequest = _reflection.GeneratedProtocolMessageType('GetBillingGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBILLINGGROUPREQUEST,
  '__module__' : 'billing.v1.billing_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.billing.v1.GetBillingGroupRequest)
  })
_sym_db.RegisterMessage(GetBillingGroupRequest)

GetBillingGroupResponse = _reflection.GeneratedProtocolMessageType('GetBillingGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBILLINGGROUPRESPONSE,
  '__module__' : 'billing.v1.billing_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.billing.v1.GetBillingGroupResponse)
  })
_sym_db.RegisterMessage(GetBillingGroupResponse)


DESCRIPTOR._options = None

_BILLING = _descriptor.ServiceDescriptor(
  name='Billing',
  full_name='blueapi.billing.v1.Billing',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\222A\231\001\022F(BETA) Billing API. Base URL: https://api.alphaus.cloud/m/blue/billing\032O\n\022Service definition\0229https://github.com/alphauslabs/blueapi/tree/main/billing/',
  create_key=_descriptor._internal_create_key,
  serialized_start=1548,
  serialized_end=2138,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListBillingGroups',
    full_name='blueapi.billing.v1.Billing.ListBillingGroups',
    index=0,
    containing_service=None,
    input_type=_LISTBILLINGGROUPSREQUEST,
    output_type=_BILLINGGROUP,
    serialized_options=b'\202\323\344\223\002\023\022\021/v1/billinggroups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateBillingGroup',
    full_name='blueapi.billing.v1.Billing.CreateBillingGroup',
    index=1,
    containing_service=None,
    input_type=_CREATEBILLINGGROUPREQUEST,
    output_type=_BILLINGGROUP,
    serialized_options=b'\202\323\344\223\002\026\"\021/v1/billinggroups:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBillingGroup',
    full_name='blueapi.billing.v1.Billing.GetBillingGroup',
    index=2,
    containing_service=None,
    input_type=_GETBILLINGGROUPREQUEST,
    output_type=_GETBILLINGGROUPRESPONSE,
    serialized_options=b'\202\323\344\223\002\'\022%/v1/billinggroups/{billingInternalId}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_BILLING)

DESCRIPTOR.services_by_name['Billing'] = _BILLING

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kvstore/v1/kvstore.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kvstore/v1/kvstore.proto',
  package='blueapi.kvstore.v1',
  syntax='proto3',
  serialized_options=b'\n\031cloud.alphaus.api.kvstoreB\014KvStoreProtoZ&github.com/alphauslabs/blueapi/kvstore',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18kvstore/v1/kvstore.proto\x12\x12\x62lueapi.kvstore.v1\x1a\x1cgoogle/api/annotations.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\"&\n\x08KeyValue\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x1b\n\x0bScanRequest\x12\x0c\n\x04like\x18\x01 \x01(\t\"\x1a\n\x0bReadRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\"\x1c\n\rDeleteRequest\x12\x0b\n\x03key\x18\x01 \x01(\t2\x8a\x04\n\x07KvStore\x12Y\n\x04Scan\x12\x1f.blueapi.kvstore.v1.ScanRequest\x1a\x1c.blueapi.kvstore.v1.KeyValue\"\x10\x82\xd3\xe4\x93\x02\n\x12\x08/v1/keys0\x01\x12]\n\x04Read\x12\x1f.blueapi.kvstore.v1.ReadRequest\x1a\x1c.blueapi.kvstore.v1.KeyValue\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/keys/{key}\x12M\n\x05Write\x12\x1c.blueapi.kvstore.v1.KeyValue\x1a\x16.google.protobuf.Empty\"\x0e\x82\xd3\xe4\x93\x02\x08\"\x03/v1:\x01*\x12[\n\x06\x44\x65lete\x12!.blueapi.kvstore.v1.DeleteRequest\x1a\x16.google.protobuf.Empty\"\x16\x82\xd3\xe4\x93\x02\x10*\x0e/v1/keys/{key}\x1a\x98\x01\x92\x41\x94\x01\x12\x41(BETA) KvStore API. Base URL: https://api.alphaus.cloud/m/blue/kv\x1aO\n\x12Service definition\x12\x39https://github.com/alphauslabs/blueapi/tree/main/kvstore/BQ\n\x19\x63loud.alphaus.api.kvstoreB\x0cKvStoreProtoZ&github.com/alphauslabs/blueapi/kvstoreb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,protoc__gen__openapiv2_dot_options_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_KEYVALUE = _descriptor.Descriptor(
  name='KeyValue',
  full_name='blueapi.kvstore.v1.KeyValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='blueapi.kvstore.v1.KeyValue.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='blueapi.kvstore.v1.KeyValue.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=193,
)


_SCANREQUEST = _descriptor.Descriptor(
  name='ScanRequest',
  full_name='blueapi.kvstore.v1.ScanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='like', full_name='blueapi.kvstore.v1.ScanRequest.like', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=195,
  serialized_end=222,
)


_READREQUEST = _descriptor.Descriptor(
  name='ReadRequest',
  full_name='blueapi.kvstore.v1.ReadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='blueapi.kvstore.v1.ReadRequest.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=250,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='blueapi.kvstore.v1.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='blueapi.kvstore.v1.DeleteRequest.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=280,
)

DESCRIPTOR.message_types_by_name['KeyValue'] = _KEYVALUE
DESCRIPTOR.message_types_by_name['ScanRequest'] = _SCANREQUEST
DESCRIPTOR.message_types_by_name['ReadRequest'] = _READREQUEST
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeyValue = _reflection.GeneratedProtocolMessageType('KeyValue', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUE,
  '__module__' : 'kvstore.v1.kvstore_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.kvstore.v1.KeyValue)
  })
_sym_db.RegisterMessage(KeyValue)

ScanRequest = _reflection.GeneratedProtocolMessageType('ScanRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCANREQUEST,
  '__module__' : 'kvstore.v1.kvstore_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.kvstore.v1.ScanRequest)
  })
_sym_db.RegisterMessage(ScanRequest)

ReadRequest = _reflection.GeneratedProtocolMessageType('ReadRequest', (_message.Message,), {
  'DESCRIPTOR' : _READREQUEST,
  '__module__' : 'kvstore.v1.kvstore_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.kvstore.v1.ReadRequest)
  })
_sym_db.RegisterMessage(ReadRequest)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREQUEST,
  '__module__' : 'kvstore.v1.kvstore_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.kvstore.v1.DeleteRequest)
  })
_sym_db.RegisterMessage(DeleteRequest)


DESCRIPTOR._options = None

_KVSTORE = _descriptor.ServiceDescriptor(
  name='KvStore',
  full_name='blueapi.kvstore.v1.KvStore',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\222A\224\001\022A(BETA) KvStore API. Base URL: https://api.alphaus.cloud/m/blue/kv\032O\n\022Service definition\0229https://github.com/alphauslabs/blueapi/tree/main/kvstore/',
  create_key=_descriptor._internal_create_key,
  serialized_start=283,
  serialized_end=805,
  methods=[
  _descriptor.MethodDescriptor(
    name='Scan',
    full_name='blueapi.kvstore.v1.KvStore.Scan',
    index=0,
    containing_service=None,
    input_type=_SCANREQUEST,
    output_type=_KEYVALUE,
    serialized_options=b'\202\323\344\223\002\n\022\010/v1/keys',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Read',
    full_name='blueapi.kvstore.v1.KvStore.Read',
    index=1,
    containing_service=None,
    input_type=_READREQUEST,
    output_type=_KEYVALUE,
    serialized_options=b'\202\323\344\223\002\020\022\016/v1/keys/{key}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Write',
    full_name='blueapi.kvstore.v1.KvStore.Write',
    index=2,
    containing_service=None,
    input_type=_KEYVALUE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\010\"\003/v1:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='blueapi.kvstore.v1.KvStore.Delete',
    index=3,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\020*\016/v1/keys/{key}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_KVSTORE)

DESCRIPTOR.services_by_name['KvStore'] = _KVSTORE

# @@protoc_insertion_point(module_scope)
